{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  var listing = [\n    {\n      \"entry\": inputs.gex_fastq_file_r1,\n      \"entryname\": \"gex_S1_L001_R1_001.fastq\",\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.gex_fastq_file_r2,\n      \"entryname\": \"gex_S1_L001_R2_001.fastq\",\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.atac_fastq_file_r1,\n      \"entryname\": \"atac_S1_L001_R1_001.fastq\",\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.atac_fastq_file_r2,\n      \"entryname\": \"atac_S1_L001_R2_001.fastq\",\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.atac_fastq_file_r3,\n      \"entryname\": \"atac_S1_L001_R3_001.fastq\",\n      \"writable\": true\n    },\n    {\n      \"entry\":`fastqs,sample,library_type\n      ${runtime.outdir},gex,Gene Expression\n      ${runtime.outdir},atac,Chromatin Accessibility`,\n      \"entryname\": \"libraries.csv\"\n    }\n  ]\n  if (inputs.gex_fastq_file_i1){\n    listing.push(\n      {\n        \"entry\": inputs.gex_fastq_file_i1,\n        \"entryname\": \"gex_S1_L001_I1_001.fastq\",\n        \"writable\": true\n      }\n    );\n  };\n  if (inputs.gex_fastq_file_i2){\n    listing.push(\n      {\n        \"entry\": inputs.gex_fastq_file_i2,\n        \"entryname\": \"gex_S1_L001_I2_001.fastq\",\n        \"writable\": true\n      }\n    );\n  };\n  if (inputs.atac_fastq_file_i1){\n    listing.push(\n      {\n        \"entry\": inputs.atac_fastq_file_i1,\n        \"entryname\": \"atac_S1_L001_I1_001.fastq\",\n        \"writable\": true\n      }\n    );\n  };\n  return listing;\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "cumulusprod/cellranger-arc:2.0.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "ATAC FASTQ index i7 file (will be staged into workdir as atac_S1_L001_I1_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/atac_fastq_file_i1"
                },
                {
                    "type": "File",
                    "doc": "ATAC FASTQ read 1 file (will be staged into workdir as atac_S1_L001_R1_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/atac_fastq_file_r1"
                },
                {
                    "type": "File",
                    "doc": "ATAC FASTQ read 2 (it's actually index i5) file (will be staged into workdir as atac_S1_L001_R2_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/atac_fastq_file_r2"
                },
                {
                    "type": "File",
                    "doc": "ATAC FASTQ read 3 (it's actually read 2) file (will be staged into workdir as atac_S1_L001_R3_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/atac_fastq_file_r3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--gex-exclude-introns"
                    },
                    "doc": "Disable counting of intronic reads. In this mode, only reads that are exonic\nand compatible with annotated splice junctions in the reference are counted.\nNote: using this mode will reduce the UMI counts in the feature-barcode matrix\n",
                    "id": "#cellranger-arc-count.cwl/exclude_introns"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--min-atac-count"
                    },
                    "doc": "Cell caller override: define the minimum number of ATAC transposition events\nin peaks (ATAC counts) for a cell barcode.\nNote: this option must be specified in conjunction with `--min-gex-count`.\nWith `--min-atac-count=X` and `--min-gex-count=Y` a barcode is defined as a cell\nif it contains at least X ATAC counts AND at least Y GEX UMI counts\n",
                    "id": "#cellranger-arc-count.cwl/force_min_atac_counts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--min-gex-count"
                    },
                    "doc": "Cell caller override: define the minimum number of GEX UMI counts for a cell barcode.\nNote: this option must be specified in conjunction with `--min-atac-count`.\nWith `--min-atac-count=X` and `--min-gex-count=Y` a barcode is defined as a cell\nif it contains at least X ATAC counts AND at least Y GEX UMI counts\n",
                    "id": "#cellranger-arc-count.cwl/force_min_gex_counts"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--peaks"
                    },
                    "doc": "Peak caller override: specify peaks to use in downstream analyses from supplied 3-column BED file.\nThe supplied peaks file must be sorted by position and not contain overlapping peaks;\ncomment lines beginning with `#` are allowed\n",
                    "id": "#cellranger-arc-count.cwl/force_peaks_bed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "GEX FASTQ index i7 file (will be staged into workdir as gex_S1_L001_I1_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/gex_fastq_file_i1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "GEX FASTQ index i5 file (will be staged into workdir as gex_S1_L001_I2_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/gex_fastq_file_i2"
                },
                {
                    "type": "File",
                    "doc": "GEX FASTQ read 1 file (will be staged into workdir as gex_S1_L001_R1_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/gex_fastq_file_r1"
                },
                {
                    "type": "File",
                    "doc": "GEX FASTQ read 2 file (will be staged into workdir as gex_S1_L001_R2_001.fastq)\n",
                    "id": "#cellranger-arc-count.cwl/gex_fastq_file_r2"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--reference"
                    },
                    "doc": "Compatible with Cell Ranger ARC reference folder that includes\nSTAR and BWA indices. Should be generated by \"cellranger-arc mkref\"\ncommand\n",
                    "id": "#cellranger-arc-count.cwl/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--localmem"
                    },
                    "doc": "Set max GB the pipeline may request at one time\nDefault: all available\n",
                    "id": "#cellranger-arc-count.cwl/memory_limit"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--localcores"
                    },
                    "doc": "Set max cores the pipeline may request at one time.\nDefault: all available\n",
                    "id": "#cellranger-arc-count.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--localvmem"
                    },
                    "doc": "Set max virtual address space in GB for the pipeline\nDefault: all available\n",
                    "id": "#cellranger-arc-count.cwl/virt_memory_limit"
                }
            ],
            "baseCommand": [
                "cellranger-arc",
                "count",
                "--disable-ui",
                "--libraries",
                "libraries.csv",
                "--id",
                "sample"
            ],
            "stdout": "cellranger_arc_count_stdout.log",
            "stderr": "cellranger_arc_count_stderr.log",
            "label": "Cell Ranger ARC count - generates single cell feature counts for a single multiome library",
            "doc": "Count ATAC and gene expression reads from a single library.\n\nCell Ranger ARC count performs alignment, filtering, barcode counting,\npeak calling and counting of both ATAC and GEX molecules. Furthermore,\nit uses the Chromium cellular barcodes to generate feature-barcode matrices,\nperform dimensionality reduction, determine clusters, perform differential\nanalysis on clusters and identify linkages between peaks and genes. The\ncount pipeline can take input from multiple sequencing runs on the same\nGEM well.\n\nParameters set by default:\n--disable-ui - no need in any UI when running in Docker container\n--id - hardcoded to `sample` to simplify output files location\n--libraries - points to the file libraries.csv generated based on the input FASTQ files\n\nNo implemented parameters:\n--no-bam - we want to always generate BAM files\n--dry\n--noexit\n--nopreflight\n--description\n--uiport\n--overrides\n--jobinterval\n--maxjobs\n--mempercore\n--jobmode (we will use local by default)\n\nWhy do we need to rename input files?\nhttps://support.10xgenomics.com/single-cell-multiome-atac-gex/software/pipelines/latest/using/using/fastq-input\n",
            "id": "#cellranger-arc-count.cwl",
            "http://schema.org/name": "Cell Ranger ARC count - generates single cell feature counts for a single multiome library",
            "http://schema.org/alternateName": "Counts ATAC and gene expression reads from a single 10x Genomics Cell Ranger Multiome ATAC + Gene Expression library",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/cellranger-arc-count.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Count ATAC and gene expression reads from a single library\n\nUSAGE:\n    cellranger-arc count [FLAGS] [OPTIONS] --id <ID> --reference <PATH> --libraries <CSV>\n\nFLAGS:\n        --gex-exclude-introns\n            Disable counting of intronic reads. In this mode, only reads that are exonic and compatible with annotated splice junctions in the reference are counted. Note: using\n            this mode will reduce the UMI counts in the feature-barcode matrix\n\n        --no-bam\n            Do not generate bam files\n\n        --dry\n            Do not execute the pipeline. Generate a pipeline invocation (.mro) file and stop\n\n        --disable-ui\n            Do not serve the web UI\n\n        --noexit\n            Keep web UI running after pipestance completes or fails\n\n        --nopreflight\n            Skip preflight checks\n\n    -h, --help\n            Prints help information\n\n\nOPTIONS:\n        --id <ID>\n            A unique run id and output folder name [a-zA-Z0-9_-]+ of maximum length 64 characters\n\n        --description <TEXT>\n            Sample description to embed in output files\n\n        --reference <PATH>\n            Path to folder containing cellranger-arc-compatible reference. Reference packages can be downloaded from support.10xgenomics.com or constructed using the `cellranger-\n            arc mkref` command\n\n        --libraries <CSV>\n            Path to 3-column CSV file defining the paths to ATAC and gene expression FASTQ data generated with the Chromium Single Cell Multiome ATAC + Gene Expression solution. A\n            template CSV would look as follows (blank lines are ignored):\n            \n            fastqs,sample,library_type\n            \n            /data/HAWT7ADXX/outs/fastq_path,myATAC,Chromatin Accessibility\n            \n            /data/H35KCBCXY/outs/fastq_path,myGEX,Gene Expression\n\n        --min-atac-count <NUM>\n            Cell caller override: define the minimum number of ATAC transposition events in peaks (ATAC counts) for a cell barcode. Note: this option must be specified in\n            conjunction with `min-gex-count`. With `--min-atac-count=X` and `--min-gex-count=Y` a barcode is defined as a cell if it contains at least X ATAC counts AND at least Y\n            GEX UMI counts\n\n        --min-gex-count <NUM>\n            Cell caller override: define the minimum number of GEX UMI counts for a cell barcode. Note: this option must be specified in conjunction with `min-atac-count`. With\n            `--min-atac-count=X` and `--min-gex-count=Y` a barcode is defined as a cell if it contains at least X ATAC counts AND at least Y GEX UMI counts\n\n        --peaks <BED>\n            Override peak caller: specify peaks to use in downstream analyses from supplied 3-column BED file. The supplied peaks file must be sorted by position and not contain\n            overlapping peaks; comment lines beginning with `#` are allowed\n\n        --jobmode <MODE>\n            Job manager to use. Valid options: local (default), sge, lsf, slurm or path to a .template file. Search for help on \"Cluster Mode\" at support.10xgenomics.com for more\n            details on configuring the pipeline to use a compute cluster [default: local]\n\n        --localcores <NUM>\n            Set max cores the pipeline may request at one time. Only applies to local jobs\n\n        --localmem <NUM>\n            Set max GB the pipeline may request at one time. Only applies to local jobs\n\n        --localvmem <NUM>\n            Set max virtual address space in GB for the pipeline. Only applies to local jobs\n\n        --mempercore <NUM>\n            Reserve enough threads for each job to ensure enough memory will be available, assuming each core on your cluster has at least this much memory available. Only applies\n            to cluster jobmodes\n\n        --maxjobs <NUM>\n            Set max jobs submitted to cluster at one time. Only applies to cluster jobmodes\n\n        --jobinterval <NUM>\n            Set delay between submitting jobs to cluster, in ms. Only applies to cluster jobmodes\n\n        --overrides <PATH>\n            The path to a JSON file that specifies stage-level overrides for cores and memory. Finer-grained than --localcores, --mempercore and --localmem. Consult\n            https://support.10xgenomics.com/ for an example override file\n\n        --uiport <PORT>\n            Serve web UI at http://localhost:PORT",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/atac_cut_sites.bigwig"
                    },
                    "doc": "Genome track of observed transposition sites in the experiment\nsmoothed at a resolution of 400 bases in BIGWIG format.\n",
                    "id": "#cellranger-arc-count.cwl/atac_cut_sites_bigwig_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/atac_fragments.tsv.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "Count and barcode information for every ATAC fragment observed in\nthe experiment in TSV format.\n",
                    "id": "#cellranger-arc-count.cwl/atac_fragments_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/atac_peak_annotation.tsv"
                    },
                    "doc": "Annotations of peaks based on genomic proximity alone.\nNote that these are not functional annotations and they\ndo not make use of linkage with GEX data.\n",
                    "id": "#cellranger-arc-count.cwl/atac_peak_annotation_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/atac_peaks.bed"
                    },
                    "doc": "Locations of open-chromatin regions identified in this sample.\nThese regions are referred to as \"peaks\".\n",
                    "id": "#cellranger-arc-count.cwl/atac_peaks_bed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/atac_possorted_bam.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "ATAC position-sorted reads aligned to the genome annotated with barcode\ninformation in BAM format\n",
                    "id": "#cellranger-arc-count.cwl/atac_possorted_genome_bam_bai"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/per_barcode_metrics.csv"
                    },
                    "doc": "ATAC and GEX read count summaries generated for every\nbarcode observed in the experiment. The columns contain\nthe paired ATAC and Gene Expression barcode sequences,\nATAC and Gene Expression QC metrics for that barcode,\nas well as whether this barcode was identified as a\ncell-associated partition by the pipeline.\nMore details:\nhttps://support.10xgenomics.com/single-cell-multiome-atac-gex/software/pipelines/latest/output/per_barcode_metrics\n",
                    "id": "#cellranger-arc-count.cwl/barcode_metrics_report"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/filtered_feature_bc_matrix"
                    },
                    "doc": "Filtered feature barcode matrix stored as a CSC sparse matrix in MEX format.\nThe rows consist of all the gene and peak features concatenated together\n(identical to raw feature barcode matrix) and the columns are restricted to\nthose barcodes that are identified as cells.\n",
                    "id": "#cellranger-arc-count.cwl/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/filtered_feature_bc_matrix.h5"
                    },
                    "doc": "Filtered feature barcode matrix stored as a CSC sparse matrix in hdf5 format.\nThe rows consist of all the gene and peak features concatenated together\n(identical to raw feature barcode matrix) and the columns are restricted to\nthose barcodes that are identified as cells.\n",
                    "id": "#cellranger-arc-count.cwl/filtered_feature_bc_matrix_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/gex_molecule_info.h5"
                    },
                    "doc": "Count and barcode information for every GEX molecule observed in the experiment\nin hdf5 format.\n",
                    "id": "#cellranger-arc-count.cwl/gex_molecule_info_h5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/gex_possorted_bam.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "GEX position-sorted reads aligned to the genome and transcriptome annotated with barcode\ninformation in BAM format\n",
                    "id": "#cellranger-arc-count.cwl/gex_possorted_genome_bam_bai"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/cloupe.cloupe"
                    },
                    "doc": "Loupe Browser visualization file with all the analysis outputs\n",
                    "id": "#cellranger-arc-count.cwl/loupe_browser_track"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/summary.csv"
                    },
                    "doc": "Run summary metrics in CSV format\n",
                    "id": "#cellranger-arc-count.cwl/metrics_summary_report"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/raw_feature_bc_matrix"
                    },
                    "doc": "Raw feature barcode matrix stored as a CSC sparse matrix in MEX format.\nThe rows consist of all the gene and peak features concatenated together\nand the columns consist of all observed barcodes with non-zero signal for\neither ATAC or gene expression.\n",
                    "id": "#cellranger-arc-count.cwl/raw_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/raw_feature_bc_matrix.h5"
                    },
                    "doc": "Raw feature barcode matrix stored as a CSC sparse matrix in hdf5 format.\nThe rows consist of all the gene and peak features concatenated together\nand the columns consist of all observed barcodes with non-zero signal for\neither ATAC or gene expression.   \n",
                    "id": "#cellranger-arc-count.cwl/raw_feature_bc_matrices_h5"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sample/outs/analysis"
                    },
                    "doc": "Various secondary analyses that utilize the ATAC data, the GEX data, and their\nlinkage: dimensionality reduction and clustering results for the ATAC and GEX\ndata, differential expression, and differential accessibility for all clustering\nresults above and linkage between ATAC and GEX data.\n",
                    "id": "#cellranger-arc-count.cwl/secondary_analysis_report_folder"
                },
                {
                    "type": "File",
                    "id": "#cellranger-arc-count.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "cellranger_arc_count_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#cellranger-arc-count.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "cellranger_arc_count_stdout.log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sample/outs/web_summary.html"
                    },
                    "doc": "Run summary metrics and charts in HTML format\n",
                    "id": "#cellranger-arc-count.cwl/web_summary_report"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Compressed or uncompressed FASTQ file(s)\n",
                    "id": "#extract-fastq.cwl/compressed_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nshopt -s nocaseglob\nset -- \"$0\" \"$@\"\n\nfunction extract {\n  FILE=$1\n  COMBINED=$2\n  T=`file -b \"${FILE}\" | awk '{print $1}'`\n  case \"${T}\" in\n    \"bzip2\"|\"gzip\"|\"Zip\")\n      7z e -so \"${FILE}\" >> \"${COMBINED}\"\n      ;;\n    \"ASCII\")\n      cat \"${FILE}\" >> \"${COMBINED}\" || true\n      ;;\n    *)\n      echo \"Error: file type unknown\"\n      rm -f \"${COMBINED}\"\n      exit 1\n  esac\n} \n\nCOMBINED=\"\"\nfor FILE in \"$@\"; do\n    BASENAME=$(basename \"$FILE\")\n    ROOTNAME=\"${BASENAME%.*}\"\n    EXT_LIST=( \".fastq\" \".fq\" )\n    for ITEM in $EXT_LIST; do\n      if [[ $ROOTNAME == *$ITEM ]]; then\n        ROOTNAME=\"${ROOTNAME%.*}\"\n      fi\n    done\n    if [[ $COMBINED == \"\" ]]; then\n      COMBINED=\"${ROOTNAME}\"\n    else\n      COMBINED=\"${COMBINED}\"_\"${ROOTNAME}\"\n    fi\ndone\nCOMBINED=\"${COMBINED}\".fastq\n\nfor FILE in \"$@\"; do\n    echo \"Extracting:\" $FILE;\n    extract \"${FILE}\" \"${COMBINED}\"\ndone;\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to extract compressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#extract-fastq.cwl/fastq_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to decompress input FASTQ file(s).\nIf several FASTQ files are provided, they will be concatenated in the order that corresponds to files in input.\nBash script's logic:\n- disable case sensitive glob check\n- check if root name of input file already include '.fastq' or '.fq' extension. If yes, set DEFAULT_EXT to \"\",\n  otherwise use '.fastq'\n- check file type, decompress if needed\n- return 1, if file type is not recognized\nThis script also works of input file doesn't have any extension at all\n",
            "id": "#extract-fastq.cwl",
            "http://schema.org/name": "extract-fastq",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/extract-fastq.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Tool to decompress input FASTQ file"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/fastqc:v0.11.5"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--adapters"
                    },
                    "doc": "Specifies a non-default file which contains the list of\nadapter sequences which will be explicity searched against\nthe library. The file must contain sets of named adapters\nin the form name[tab]sequence.  Lines prefixed with a hash\nwill be ignored.\n",
                    "id": "#fastqc.cwl/adapters"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--casava"
                    },
                    "doc": "Files come from raw casava output. Files in the same sample\ngroup (differing only by the group number) will be analysed\nas a set rather than individually. Sequences with the filter\nflag set in the header will be excluded from the analysis.\nFiles must have the same names given to them by casava\n(including being gzipped and ending with .gz) otherwise they\nwon't be grouped together correctly.\n",
                    "id": "#fastqc.cwl/casava"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--contaminants"
                    },
                    "doc": "Specifies a non-default file which contains the list of\ncontaminants to screen overrepresented sequences against.\nThe file must contain sets of named contaminants in the\nform name[tab]sequence.  Lines prefixed with a hash will\nbe ignored.\n",
                    "id": "#fastqc.cwl/contaminants"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#fastqc.cwl/format_enum/format",
                            "symbols": [
                                "#fastqc.cwl/format_enum/format/bam",
                                "#fastqc.cwl/format_enum/format/sam",
                                "#fastqc.cwl/format_enum/format/bam_mapped",
                                "#fastqc.cwl/format_enum/format/sam_mapped",
                                "#fastqc.cwl/format_enum/format/fastq"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--format"
                    },
                    "doc": "Bypasses the normal sequence file format detection and\nforces the program to use the specified format.  Valid\nformats are bam,sam,bam_mapped,sam_mapped and fastq\n",
                    "id": "#fastqc.cwl/format_enum"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--nogroup"
                    },
                    "doc": "Disable grouping of bases for reads >50bp. All reports will\nshow data for every base in the read.  WARNING: Using this\noption will cause fastqc to crash and burn if you use it on\nreally long reads, and your plots may end up a ridiculous size.\nYou have been warned!\n",
                    "id": "#fastqc.cwl/hide_group"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--kmers"
                    },
                    "doc": "Specifies the length of Kmer to look for in the Kmer content\nmodule. Specified Kmer length must be between 2 and 10. Default\nlength is 7 if not specified.\n",
                    "id": "#fastqc.cwl/kmers"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--limits"
                    },
                    "doc": "Specifies a non-default file which contains a set of criteria\nwhich will be used to determine the warn/error limits for the\nvarious modules.  This file can also be used to selectively\nremove some modules from the output all together.  The format\nneeds to mirror the default limits.txt file found in the\nConfiguration folder.\n",
                    "id": "#fastqc.cwl/limits"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--nofilter"
                    },
                    "doc": "If running with --casava then don't remove read flagged by\ncasava as poor quality when performing the QC analysis.\n",
                    "id": "#fastqc.cwl/nofilter"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 50
                    },
                    "doc": "Input bam,sam,bam_mapped,sam_mapped or fastq file\n",
                    "id": "#fastqc.cwl/reads_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--threads"
                    },
                    "doc": "Specifies the number of files which can be processed\nsimultaneously.  Each thread will be allocated 250MB of\nmemory so you shouldn't run more threads than your\navailable memory will cope with, and not more than\n6 threads on a 32 bit machine\n",
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#fastqc.cwl/html_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return \"*/summary.txt\";\n}\n"
                    },
                    "id": "#fastqc.cwl/summary_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.zip"
                    },
                    "id": "#fastqc.cwl/zipped_file"
                }
            ],
            "baseCommand": [
                "fastqc",
                "--extract",
                "--outdir",
                "."
            ],
            "doc": "Tool runs FastQC from Babraham Bioinformatics\n",
            "id": "#fastqc.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#fastqc-metadata.yaml",
                "http://schema.org/name": "fastqc",
                "http://schema.org/about": "FastQC is a program designed to spot potential problems in high througput sequencing datasets.\nIt runs a set of analyses on one or more raw sequence files in fastq or bam format and produces\na report which summarises the results.\n",
                "http://schema.org/url": "http://www.bioinformatics.babraham.ac.uk/projects/fastqc/",
                "http://schema.org/codeRepository": "https://github.com/s-andrews/FastQC/releases",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.11.5",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/discussionUrl": [
                    "https://github.com/s-andrews/FastQC/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Babraham Bioinformatics",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Simon Andrews"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastqc",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastqc.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "SYNOPSIS\n\n    fastqc seqfile1 seqfile2 .. seqfileN\n\n    fastqc [-o output dir] [--(no)extract] [-f fastq|bam|sam]\n           [-c contaminant file] seqfile1 .. seqfileN\n\nDESCRIPTION\n\n    FastQC reads a set of sequence files and produces from each one a quality\n    control report consisting of a number of different modules, each one of\n    which will help to identify a different potential type of problem in your\n    data.\n\n    If no files to process are specified on the command line then the program\n    will start as an interactive graphical application.  If files are provided\n    on the command line then the program will run with no user interaction\n    required.  In this mode it is suitable for inclusion into a standardised\n    analysis pipeline.\n\n    The options for the program as as follows:\n\n    -h --help       Print this help file and exit\n\n    -v --version    Print the version of the program and exit\n\n    -o --outdir     Create all output files in the specified output directory.\n                    Please note that this directory must exist as the program\n                    will not create it.  If this option is not set then the\n                    output file for each sequence file is created in the same\n                    directory as the sequence file which was processed.\n\n    --casava        Files come from raw casava output. Files in the same sample\n                    group (differing only by the group number) will be analysed\n                    as a set rather than individually. Sequences with the filter\n                    flag set in the header will be excluded from the analysis.\n                    Files must have the same names given to them by casava\n                    (including being gzipped and ending with .gz) otherwise they\n                    won't be grouped together correctly.\n\n    --nano          Files come from naopore sequences and are in fast5 format. In\n                    this mode you can pass in directories to process and the program\n                    will take in all fast5 files within those directories and produce\n                    a single output file from the sequences found in all files.\n\n    --nofilter      If running with --casava then don't remove read flagged by\n                    casava as poor quality when performing the QC analysis.\n\n    --extract       If set then the zipped output file will be uncompressed in\n                    the same directory after it has been created.  By default\n                    this option will be set if fastqc is run in non-interactive\n                    mode.\n\n    -j --java       Provides the full path to the java binary you want to use to\n                    launch fastqc. If not supplied then java is assumed to be in\n                    your path.\n\n    --noextract     Do not uncompress the output file after creating it.  You\n                    should set this option if you do not wish to uncompress\n                    the output when running in non-interactive mode.\n\n    --nogroup       Disable grouping of bases for reads >50bp. All reports will\n                    show data for every base in the read.  WARNING: Using this\n                    option will cause fastqc to crash and burn if you use it on\n                    really long reads, and your plots may end up a ridiculous size.\n                    You have been warned!\n\n    -f --format     Bypasses the normal sequence file format detection and\n                    forces the program to use the specified format.  Valid\n                    formats are bam,sam,bam_mapped,sam_mapped and fastq\n\n    -t --threads    Specifies the number of files which can be processed\n                    simultaneously.  Each thread will be allocated 250MB of\n                    memory so you shouldn't run more threads than your\n                    available memory will cope with, and not more than\n                    6 threads on a 32 bit machine\n\n    -c              Specifies a non-default file which contains the list of\n    --contaminants  contaminants to screen overrepresented sequences against.\n                    The file must contain sets of named contaminants in the\n                    form name[tab]sequence.  Lines prefixed with a hash will\n                    be ignored.\n\n    -a              Specifies a non-default file which contains the list of\n    --adapters      adapter sequences which will be explicity searched against\n                    the library. The file must contain sets of named adapters\n                    in the form name[tab]sequence.  Lines prefixed with a hash\n                    will be ignored.\n\n    -l              Specifies a non-default file which contains a set of criteria\n    --limits        which will be used to determine the warn/error limits for the\n                    various modules.  This file can also be used to selectively\n                    remove some modules from the output all together.  The format\n                    needs to mirror the default limits.txt file found in the\n                    Configuration folder.\n\n   -k --kmers       Specifies the length of Kmer to look for in the Kmer content\n                    module. Specified Kmer length must be between 2 and 10. Default\n                    length is 7 if not specified.\n\n   -q --quiet       Supress all progress messages on stdout and only report errors.\n\n   -d --dir         Selects a directory to be used for temporary files written when\n                    generating report images. Defaults to system temp directory if\n                    not specified.\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Folder to compressed",
                    "id": "#tar-compress.cwl/folder_to_compress"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Compressed folder",
                    "id": "#tar-compress.cwl/compressed_folder"
                }
            ],
            "baseCommand": [
                "tar"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.folder_to_compress.path.split(\"/\").slice(0,-1).join(\"/\"))",
                    "prefix": "-C"
                },
                "-czvf",
                {
                    "valueFrom": "$(inputs.folder_to_compress.basename + \".tar.gz\")"
                },
                "."
            ],
            "doc": "Compresses input directory to tar.gz\n",
            "id": "#tar-compress.cwl",
            "http://schema.org/name": "tar-compress",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/tar-compress.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "genome_indices": [
                    "cellranger-mkref.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "ATAC FASTQ file R1 (optionally compressed)",
                    "doc": "ATAC FASTQ file R1 (optionally compressed)",
                    "id": "#main/atac_fastq_file_r1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "ATAC FASTQ file R2 (optionally compressed)",
                    "doc": "ATAC FASTQ file R2 (optionally compressed)",
                    "id": "#main/atac_fastq_file_r2"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "ATAC FASTQ file R3 (optionally compressed)",
                    "doc": "ATAC FASTQ file R3 (optionally compressed)",
                    "id": "#main/atac_fastq_file_r3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Disable counting of intronic reads",
                    "doc": "Disable counting of intronic reads. In this mode, only reads that are exonic\nand compatible with annotated splice junctions in the reference are counted.\nNote: using this mode will reduce the UMI counts in the feature-barcode matrix\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/exclude_introns"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "GEX FASTQ file R1 (optionally compressed)",
                    "doc": "GEX FASTQ file R1 (optionally compressed)",
                    "id": "#main/gex_fastq_file_r1"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "GEX FASTQ file R2 (optionally compressed)",
                    "doc": "GEX FASTQ file R2 (optionally compressed)",
                    "id": "#main/gex_fastq_file_r2"
                },
                {
                    "type": "Directory",
                    "label": "Genome Type",
                    "doc": "Cell Ranger ARC generated genome indices folder",
                    "sd:upstreamSource": "genome_indices/arc_indices_folder",
                    "sd:localLabel": true,
                    "id": "#main/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "label": "Genome Type",
                    "doc": "Maximum memory used (GB).\nThe same as was used for generating indices.\nThe same will be applied to virtual memory\n",
                    "sd:upstreamSource": "genome_indices/memory_limit",
                    "sd:localLabel": true,
                    "id": "#main/memory_limit"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/atac_cut_sites_bigwig_file",
                    "label": "Observed transposition sites in bigWig format",
                    "doc": "Genome track of observed transposition sites in the experiment\nsmoothed at a resolution of 400 bases in BIGWIG format.\n",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/atac_cut_sites_bigwig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/atac_cut_sites_bigwig_file/ATAC cut sites",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/atac_cut_sites_bigwig_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/atac_fragments_file",
                    "label": "Count and barcode information for every ATAC fragment in TSV format",
                    "doc": "Count and barcode information for every ATAC fragment observed in\nthe experiment in TSV format.\n",
                    "id": "#main/atac_fragments_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/atac_peak_annotation_file",
                    "label": "Annotations of peaks based on genomic proximity in TSV format",
                    "doc": "Annotations of peaks based on genomic proximity alone.\nNote that these are not functional annotations and they\ndo not make use of linkage with GEX data.\n",
                    "id": "#main/atac_peak_annotation_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/atac_peaks_bed_file",
                    "label": "Identified peaks in BED format",
                    "doc": "Locations of open-chromatin regions identified in this sample.\nThese regions are referred to as \"peaks\".\n",
                    "id": "#main/atac_peaks_bed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/atac_possorted_genome_bam_bai",
                    "label": "Aligned to the genome indexed reads ATAC BAM+BAI files",
                    "doc": "ATAC position-sorted reads aligned to the genome annotated with\nbarcode information in BAM format\n",
                    "id": "#main/atac_possorted_genome_bam_bai"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/barcode_metrics_report",
                    "label": "ATAC and GEX barcode metrics in CSV format",
                    "doc": "ATAC and GEX read count summaries generated for every\nbarcode observed in the experiment. The columns contain\nthe paired ATAC and Gene Expression barcode sequences,\nATAC and Gene Expression QC metrics for that barcode,\nas well as whether this barcode was identified as a\ncell-associated partition by the pipeline.\n",
                    "id": "#main/barcode_metrics_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_statistics/collected_statistics",
                    "label": "Collected statistics in Markdown format",
                    "doc": "Collected statistics in Markdown format",
                    "sd:visualPlugins": [
                        {
                            "markdownView": {
                                "tab": "Overview"
                            }
                        }
                    ],
                    "id": "#main/collected_statistics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_atac_fastq_r1/html_file",
                    "label": "FastqQC report for ATAC FASTQ file R1",
                    "doc": "FastqQC report for ATAC FASTQ file R1\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/fastqc_report_atac_fastq_r1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_atac_fastq_r2/html_file",
                    "label": "FastqQC report for ATAC FASTQ file R2",
                    "doc": "FastqQC report for ATAC FASTQ file R2\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/fastqc_report_atac_fastq_r2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_atac_fastq_r3/html_file",
                    "label": "FastqQC report for ATAC FASTQ file R3",
                    "doc": "FastqQC report for ATAC FASTQ file R3\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/fastqc_report_atac_fastq_r3"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_gex_fastq_r1/html_file",
                    "label": "FastqQC report for GEX FASTQ file R1",
                    "doc": "FastqQC report for GEX FASTQ file R1\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/fastqc_report_gex_fastq_r1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fastqc_for_gex_fastq_r2/html_file",
                    "label": "FastqQC report for GEX FASTQ file R2",
                    "doc": "FastqQC report for GEX FASTQ file R2\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/fastqc_report_gex_fastq_r2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_filtered_feature_bc_matrix_folder/compressed_folder",
                    "label": "Compressed folder with filtered feature-barcode matrices",
                    "doc": "Filtered feature barcode matrix stored as a CSC sparse matrix in MEX format.\nThe rows consist of all the gene and peak features concatenated together\n(identical to raw feature barcode matrix) and the columns are restricted to\nthose barcodes that are identified as cells.\n",
                    "id": "#main/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/filtered_feature_bc_matrix_h5",
                    "label": "Filtered feature-barcode matrices in HDF5 format",
                    "doc": "Filtered feature barcode matrix stored as a CSC sparse matrix in hdf5 format.\nThe rows consist of all the gene and peak features concatenated together\n(identical to raw feature barcode matrix) and the columns are restricted to\nthose barcodes that are identified as cells.\n",
                    "id": "#main/filtered_feature_bc_matrix_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/stderr_log",
                    "label": "stderr log generated by cellranger-arc count",
                    "doc": "stderr log generated by cellranger-arc count\n",
                    "id": "#main/generate_counts_matrix_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/stdout_log",
                    "label": "stdout log generated by cellranger-arc count",
                    "doc": "stdout log generated by cellranger-arc count\n",
                    "id": "#main/generate_counts_matrix_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/gex_molecule_info_h5",
                    "label": "GEX molecule-level information for aggregating samples into larger datasets",
                    "doc": "Count and barcode information for every GEX molecule observed in the experiment\nin hdf5 format\n",
                    "id": "#main/gex_molecule_info_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/gex_possorted_genome_bam_bai",
                    "label": "Aligned to the genome indexed reads GEX BAM+BAI files",
                    "doc": "GEX position-sorted reads aligned to the genome and transcriptome\nannotated with barcode information in BAM format\n",
                    "id": "#main/gex_possorted_genome_bam_bai"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/loupe_browser_track",
                    "label": "Loupe Browser visualization file with all the analysis outputs",
                    "doc": "Loupe Browser visualization file with all the analysis outputs\n",
                    "id": "#main/loupe_browser_track"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/metrics_summary_report",
                    "label": "Run summary metrics in CSV format",
                    "doc": "Run summary metrics in CSV format\n",
                    "id": "#main/metrics_summary_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_raw_feature_bc_matrices_folder/compressed_folder",
                    "label": "Compressed folder with unfiltered feature-barcode matrices",
                    "doc": "Raw feature barcode matrix stored as a CSC sparse matrix in MEX format.\nThe rows consist of all the gene and peak features concatenated together\nand the columns consist of all observed barcodes with non-zero signal for\neither ATAC or gene expression.\n",
                    "id": "#main/raw_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/raw_feature_bc_matrices_h5",
                    "label": "Unfiltered feature-barcode matrices in HDF5 format",
                    "doc": "Raw feature barcode matrix stored as a CSC sparse matrix in hdf5 format.\nThe rows consist of all the gene and peak features concatenated together\nand the columns consist of all observed barcodes with non-zero signal for\neither ATAC or gene expression.\n",
                    "id": "#main/raw_feature_bc_matrices_h5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_secondary_analysis_report_folder/compressed_folder",
                    "label": "Compressed folder with secondary analysis results",
                    "doc": "Various secondary analyses that utilize the ATAC data, the GEX data, and their\nlinkage: dimensionality reduction and clustering results for the ATAC and GEX\ndata, differential expression, and differential accessibility for all clustering\nresults above and linkage between ATAC and GEX data.\n",
                    "id": "#main/secondary_analysis_report_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_counts_matrix/web_summary_report",
                    "label": "Cell Ranger summary",
                    "doc": "Cell Ranger summary\n",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/web_summary_report"
                }
            ],
            "steps": [
                {
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "hints": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "rackspacedot/python37"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 6
                                },
                                "id": "#main/collect_statistics/3ed0301c-75a0-41d7-aa9c-a0df6c1ff20c/metrics_summary_report"
                            },
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "default": "#!/usr/bin/env python3\nimport sys, csv\nwith open(sys.argv[1], \"r\") as input_stream:\n  with open(\"collected_statistics.md\", \"w\") as output_stream:\n    output_stream.write(\"### Cell Ranger ARC Statistics\\n\")\n    keys, values = None, None\n    for i, row in enumerate(csv.reader(input_stream)):\n      if i==0:\n        keys = row\n      else:\n        values = row\n    for k,v in zip(keys, values):\n      output_stream.write(\"- \"+k+\": \"+v+\"\\n\")\n",
                                "inputBinding": {
                                    "position": 5
                                },
                                "id": "#main/collect_statistics/3ed0301c-75a0-41d7-aa9c-a0df6c1ff20c/script"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/collect_statistics/3ed0301c-75a0-41d7-aa9c-a0df6c1ff20c/collected_statistics"
                            }
                        ],
                        "baseCommand": [
                            "python3",
                            "-c"
                        ],
                        "id": "#main/collect_statistics/3ed0301c-75a0-41d7-aa9c-a0df6c1ff20c"
                    },
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/metrics_summary_report",
                            "id": "#main/collect_statistics/metrics_summary_report"
                        }
                    ],
                    "out": [
                        "#main/collect_statistics/collected_statistics"
                    ],
                    "id": "#main/collect_statistics"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/filtered_feature_bc_matrix_folder",
                            "id": "#main/compress_filtered_feature_bc_matrix_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_filtered_feature_bc_matrix_folder/compressed_folder"
                    ],
                    "id": "#main/compress_filtered_feature_bc_matrix_folder"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/raw_feature_bc_matrices_folder",
                            "id": "#main/compress_raw_feature_bc_matrices_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_raw_feature_bc_matrices_folder/compressed_folder"
                    ],
                    "id": "#main/compress_raw_feature_bc_matrices_folder"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/generate_counts_matrix/secondary_analysis_report_folder",
                            "id": "#main/compress_secondary_analysis_report_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_secondary_analysis_report_folder/compressed_folder"
                    ],
                    "id": "#main/compress_secondary_analysis_report_folder"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/atac_fastq_file_r1",
                            "id": "#main/extract_atac_fastq_r1/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_atac_fastq_r1/fastq_file"
                    ],
                    "id": "#main/extract_atac_fastq_r1"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/atac_fastq_file_r2",
                            "id": "#main/extract_atac_fastq_r2/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_atac_fastq_r2/fastq_file"
                    ],
                    "id": "#main/extract_atac_fastq_r2"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/atac_fastq_file_r3",
                            "id": "#main/extract_atac_fastq_r3/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_atac_fastq_r3/fastq_file"
                    ],
                    "id": "#main/extract_atac_fastq_r3"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/gex_fastq_file_r1",
                            "id": "#main/extract_gex_fastq_r1/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_gex_fastq_r1/fastq_file"
                    ],
                    "id": "#main/extract_gex_fastq_r1"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/gex_fastq_file_r2",
                            "id": "#main/extract_gex_fastq_r2/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_gex_fastq_r2/fastq_file"
                    ],
                    "id": "#main/extract_gex_fastq_r2"
                },
                {
                    "run": "#cellranger-arc-count.cwl",
                    "in": [
                        {
                            "source": "#main/extract_atac_fastq_r1/fastq_file",
                            "id": "#main/generate_counts_matrix/atac_fastq_file_r1"
                        },
                        {
                            "source": "#main/extract_atac_fastq_r2/fastq_file",
                            "id": "#main/generate_counts_matrix/atac_fastq_file_r2"
                        },
                        {
                            "source": "#main/extract_atac_fastq_r3/fastq_file",
                            "id": "#main/generate_counts_matrix/atac_fastq_file_r3"
                        },
                        {
                            "source": "#main/exclude_introns",
                            "id": "#main/generate_counts_matrix/exclude_introns"
                        },
                        {
                            "source": "#main/extract_gex_fastq_r1/fastq_file",
                            "id": "#main/generate_counts_matrix/gex_fastq_file_r1"
                        },
                        {
                            "source": "#main/extract_gex_fastq_r2/fastq_file",
                            "id": "#main/generate_counts_matrix/gex_fastq_file_r2"
                        },
                        {
                            "source": "#main/indices_folder",
                            "id": "#main/generate_counts_matrix/indices_folder"
                        },
                        {
                            "source": "#main/memory_limit",
                            "id": "#main/generate_counts_matrix/memory_limit"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/generate_counts_matrix/threads"
                        },
                        {
                            "source": "#main/memory_limit",
                            "id": "#main/generate_counts_matrix/virt_memory_limit"
                        }
                    ],
                    "out": [
                        "#main/generate_counts_matrix/web_summary_report",
                        "#main/generate_counts_matrix/metrics_summary_report",
                        "#main/generate_counts_matrix/barcode_metrics_report",
                        "#main/generate_counts_matrix/gex_possorted_genome_bam_bai",
                        "#main/generate_counts_matrix/atac_possorted_genome_bam_bai",
                        "#main/generate_counts_matrix/filtered_feature_bc_matrix_folder",
                        "#main/generate_counts_matrix/filtered_feature_bc_matrix_h5",
                        "#main/generate_counts_matrix/raw_feature_bc_matrices_folder",
                        "#main/generate_counts_matrix/raw_feature_bc_matrices_h5",
                        "#main/generate_counts_matrix/secondary_analysis_report_folder",
                        "#main/generate_counts_matrix/gex_molecule_info_h5",
                        "#main/generate_counts_matrix/loupe_browser_track",
                        "#main/generate_counts_matrix/atac_fragments_file",
                        "#main/generate_counts_matrix/atac_peaks_bed_file",
                        "#main/generate_counts_matrix/atac_cut_sites_bigwig_file",
                        "#main/generate_counts_matrix/atac_peak_annotation_file",
                        "#main/generate_counts_matrix/stdout_log",
                        "#main/generate_counts_matrix/stderr_log"
                    ],
                    "id": "#main/generate_counts_matrix"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_atac_fastq_r1/fastq_file",
                            "id": "#main/run_fastqc_for_atac_fastq_r1/reads_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_fastqc_for_atac_fastq_r1/threads"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_atac_fastq_r1/html_file"
                    ],
                    "id": "#main/run_fastqc_for_atac_fastq_r1"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_atac_fastq_r2/fastq_file",
                            "id": "#main/run_fastqc_for_atac_fastq_r2/reads_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_fastqc_for_atac_fastq_r2/threads"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_atac_fastq_r2/html_file"
                    ],
                    "id": "#main/run_fastqc_for_atac_fastq_r2"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_atac_fastq_r3/fastq_file",
                            "id": "#main/run_fastqc_for_atac_fastq_r3/reads_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_fastqc_for_atac_fastq_r3/threads"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_atac_fastq_r3/html_file"
                    ],
                    "id": "#main/run_fastqc_for_atac_fastq_r3"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_gex_fastq_r1/fastq_file",
                            "id": "#main/run_fastqc_for_gex_fastq_r1/reads_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_fastqc_for_gex_fastq_r1/threads"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_gex_fastq_r1/html_file"
                    ],
                    "id": "#main/run_fastqc_for_gex_fastq_r1"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_gex_fastq_r2/fastq_file",
                            "id": "#main/run_fastqc_for_gex_fastq_r2/reads_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_fastqc_for_gex_fastq_r2/threads"
                        }
                    ],
                    "out": [
                        "#main/run_fastqc_for_gex_fastq_r2/html_file"
                    ],
                    "id": "#main/run_fastqc_for_gex_fastq_r2"
                }
            ],
            "label": "Cell Ranger ARC Count Gene Expression + ATAC",
            "doc": "Cell Ranger ARC Count Gene Expression + ATAC\n============================================",
            "id": "#main",
            "http://schema.org/name": "Cell Ranger ARC Count Gene Expression + ATAC",
            "http://schema.org/alternateName": "Counts ATAC and gene expression reads from a single 10x Genomics Cell Ranger Multiome ATAC + Gene Expression library",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/cellranger-arc-count.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
